[Python-modules-commits] [pyqt5] 01/03: Import pyqt5_5.7.1+dfsg.orig.tar.gz

Dmitry Shachnev mitya57 at moszumanska.debian.org
Fri Dec 30 21:24:00 UTC 2016


This is an automated email from the git hooks/post-receive script.

mitya57 pushed a commit to branch master
in repository pyqt5.

commit 6af41bd8c615d2ec9d23b7187ad4d4b7b44b8c3f
Author: Dmitry Shachnev <mitya57 at gmail.com>
Date:   Sat Dec 31 00:03:18 2016 +0300

    Import pyqt5_5.7.1+dfsg.orig.tar.gz
---
 ChangeLog                                          | 505 ++++++++++++++++++++-
 NEWS                                               |   9 +
 configure.py                                       |  42 +-
 designer/pluginloader.cpp                          | 242 +++++-----
 designer/pluginloader.h                            |  10 +
 doc/sphinx/api/qopenglversionprofile.rst           |   8 +
 doc/sphinx/api/qquickwebengineprofile.rst          |   8 +
 doc/sphinx/api_metadata.cfg                        |   3 +
 doc/sphinx/conf.py                                 |   6 +-
 doc/sphinx/deploy_commercial.rst                   |   2 +-
 doc/sphinx/extension_api.rst                       |   2 +-
 doc/sphinx/installation.rst                        |  26 +-
 doc/sphinx/introduction.rst                        |  27 +-
 doc/sphinx/pyqt4_differences.rst                   |   2 +-
 pylupdate/pylupdate_main.py                        |  53 ++-
 pylupdate/pylupdatemod.sip                         |   5 +-
 pyrcc/pyrccmod.sip                                 |   2 +-
 pyuic/uic/objcreator.py                            |  28 +-
 pyuic/uic/port_v2/load_plugin.py                   |  43 --
 pyuic/uic/port_v3/load_plugin.py                   |  43 --
 pyuic/uic/pyuic.py                                 |  29 +-
 pyuic/uic/uiparser.py                              |  14 +-
 .../invoke.py => widget-plugins/qtcharts.py}       |  33 +-
 .../qtwebenginewidgets.py}                         |  33 +-
 qpy/QtCore/qpycore_chimera.cpp                     |  55 +--
 qpy/QtCore/qpycore_classinfo.cpp                   |  14 +-
 qpy/QtCore/qpycore_decorators.cpp                  |   2 +-
 qpy/QtCore/qpycore_enums_flags.cpp                 |  24 +-
 qpy/QtCore/qpycore_init.cpp                        |  11 -
 qpy/QtCore/qpycore_misc.cpp                        |   6 +-
 qpy/QtCore/qpycore_objectified_strings.h           |   5 +
 qpy/QtCore/qpycore_post_init.cpp.in                |  46 +-
 qpy/QtCore/qpycore_public_api.cpp                  |  27 +-
 qpy/QtCore/qpycore_pyqtboundsignal.cpp             | 134 ++++--
 qpy/QtCore/qpycore_pyqtboundsignal.h               |   7 +-
 qpy/QtCore/qpycore_pyqtconfigure.cpp               |   2 +-
 qpy/QtCore/qpycore_pyqtmethodproxy.cpp             |  55 ++-
 qpy/QtCore/qpycore_pyqtmethodproxy.h               |   8 +-
 qpy/QtCore/qpycore_pyqtproperty.cpp                |  63 ++-
 qpy/QtCore/qpycore_pyqtproperty.h                  |   9 +-
 qpy/QtCore/qpycore_pyqtpyobject.cpp                |   4 +-
 qpy/QtCore/qpycore_pyqtsignal.cpp                  | 107 +++--
 qpy/QtCore/qpycore_pyqtsignal.h                    |   7 +-
 qpy/QtCore/qpycore_pyqtslot.cpp                    |  44 +-
 qpy/QtCore/qpycore_qjsonvalue.cpp                  |   2 +-
 qpy/QtCore/qpycore_qmessagelogger.cpp              |   4 +-
 qpy/QtCore/qpycore_qmetaobject.cpp                 |   6 +-
 qpy/QtCore/qpycore_qmetaobject_helpers.cpp         |   8 +-
 qpy/QtCore/qpycore_qobject_getattr.cpp             |   4 +-
 qpy/QtCore/qpycore_qobject_helpers.cpp             | 123 +++--
 qpy/QtCore/qpycore_qstring.cpp                     |  48 +-
 qpy/QtCore/qpycore_qvariant_value.cpp              |   2 +-
 qpy/QtCore/qpycore_types.cpp                       | 271 ++++-------
 qpy/QtCore/qpycore_types.h                         |  30 +-
 qpy/QtDBus/qpydbus_chimera_helpers.cpp             |   4 +-
 qpy/QtGui/qpyopengl_array_convertors.cpp           |  10 +-
 qpy/QtGui/qpyopengl_attribute_array.cpp            |  20 +-
 qpy/QtGui/qpyopengl_data_cache.cpp                 |  57 ++-
 qpy/QtGui/qpyopengl_data_cache.h                   |  14 +-
 qpy/QtGui/qpyopengl_init.cpp                       |   2 +-
 .../qpyopengl_misc.h}                              |  16 +-
 qpy/QtGui/qpyopengl_uniform_value_array.cpp        |  19 +-
 qpy/QtGui/qpyopengl_value_array.cpp                |  33 +-
 qpy/QtGui/qpyopengl_version_functions.cpp          |   2 +-
 qpy/QtQml/qpyqml_post_init.cpp                     |  14 +-
 qpy/QtQml/qpyqml_qjsvalue.cpp                      |   2 +-
 qpy/QtQml/qpyqml_register_singleton_type.cpp       |   2 +-
 qpy/QtQml/qpyqml_register_type.cpp                 |   4 +-
 qpy/QtQml/qpyqmllistproperty.cpp                   |  70 ++-
 qpy/QtQml/qpyqmllistproperty.h                     |   7 +-
 qpy/QtQml/qpyqmllistpropertywrapper.cpp            |  81 +++-
 qpy/QtQml/qpyqmllistpropertywrapper.h              |   7 +-
 qpy/QtQml/qpyqmlobject.cpp                         |   5 +-
 qpy/QtQml/qpyqmlobject.h                           |   2 +-
 qpy/QtQuick/qpyquick_chimera_helpers.cpp           |   8 +-
 qpy/pylupdate/merge.cpp                            |   5 +-
 qpy/pylupdate/pylupdate.h                          |   3 +-
 sip/Enginio/Enginiomod.sip                         |   2 +-
 sip/QAxContainer/QAxContainermod.sip               |   2 +-
 sip/QAxContainer/qaxbase.sip                       |   4 +-
 sip/QAxContainer/qaxobject.sip                     |  10 +-
 sip/QtBluetooth/QtBluetoothmod.sip                 |   2 +-
 sip/QtBluetooth/qpybluetooth_qlist.sip             |   8 +-
 sip/QtBluetooth/qpybluetooth_quint128.sip          |   6 +-
 sip/QtCore/QtCoremod.sip                           |   5 +-
 sip/QtCore/qabstracttransition.sip                 |  13 +-
 sip/QtCore/qbuffer.sip                             |   4 +-
 sip/QtCore/qbytearray.sip                          |  13 +-
 sip/QtCore/qchar.sip                               |   4 +-
 sip/QtCore/qcoreapplication.sip                    |  26 +-
 sip/QtCore/qdatetime.sip                           | 100 ++--
 sip/QtCore/qglobal.sip                             |   4 +-
 sip/QtCore/qiodevice.sip                           |   8 +-
 sip/QtCore/qjsonarray.sip                          |   4 +-
 sip/QtCore/qjsonobject.sip                         |   4 +-
 sip/QtCore/qlocale.sip                             | 109 ++++-
 sip/QtCore/qobject.sip                             |  24 +-
 sip/QtCore/qpycore_qhash.sip                       |  12 +-
 sip/QtCore/qpycore_qlist.sip                       |  44 +-
 sip/QtCore/qpycore_qmap.sip                        |  10 +-
 sip/QtCore/qpycore_qpair.sip                       |  16 +-
 sip/QtCore/qpycore_qset.sip                        |   4 +-
 sip/QtCore/qpycore_qvector.sip                     |  20 +-
 sip/QtCore/qstatemachine.sip                       |  13 +-
 sip/QtCore/qstring.sip                             |   2 +-
 sip/QtCore/qstringlist.sip                         |   4 +-
 sip/QtDBus/QtDBusmod.sip                           |   2 +-
 sip/QtDesigner/QtDesignermod.sip                   |   2 +-
 sip/QtGui/QtGuimod.sip                             |   2 +-
 sip/QtGui/qdesktopservices.sip                     |  28 +-
 sip/QtGui/qfontmetrics.sip                         |   6 +-
 sip/QtGui/qmatrix4x4.sip                           |   2 +-
 sip/QtGui/qpainter.sip                             |  40 +-
 sip/QtGui/qpolygon.sip                             |  24 +-
 sip/QtGui/qpygui_qlist.sip                         |   6 +-
 sip/QtGui/qpygui_qpair.sip                         |  16 +-
 sip/QtGui/qpygui_qvector.sip                       |  16 +-
 sip/QtGui/qregion.sip                              |   8 +
 sip/QtHelp/QtHelpmod.sip                           |   2 +-
 sip/QtLocation/QtLocationmod.sip                   |   2 +-
 sip/QtMacExtras/QtMacExtrasmod.sip                 |   3 +-
 .../QtMacExtras/qtmac.sip                          |  30 +-
 sip/QtMultimedia/QtMultimediamod.sip               |   2 +-
 sip/QtMultimedia/qpymultimedia_qlist.sip           |  16 +-
 sip/QtMultimediaWidgets/QtMultimediaWidgetsmod.sip |   2 +-
 sip/QtNetwork/QtNetworkmod.sip                     |   2 +-
 sip/QtNetwork/qhostaddress.sip                     |   4 +-
 sip/QtNetwork/qpynetwork_qhash.sip                 |   2 +-
 sip/QtNetwork/qpynetwork_qmap.sip                  |   4 +-
 sip/QtNfc/QtNfcmod.sip                             |   2 +-
 sip/QtOpenGL/QtOpenGLmod.sip                       |   2 +-
 sip/QtPositioning/QtPositioningmod.sip             |   2 +-
 sip/QtPrintSupport/QtPrintSupportmod.sip           |   2 +-
 sip/QtPrintSupport/qpyprintsupport_qlist.sip       |   8 +-
 sip/QtQml/QtQmlmod.sip                             |   2 +-
 sip/QtQml/qpyqmllistproperty.sip                   |   2 +-
 sip/QtQuick/QtQuickmod.sip                         |   2 +-
 sip/QtQuick/qsggeometry.sip                        |   6 +-
 sip/QtQuick/qsgmaterial.sip                        |  20 +-
 sip/QtQuickWidgets/QtQuickWidgetsmod.sip           |   2 +-
 sip/QtSensors/QtSensorsmod.sip                     |   2 +-
 sip/QtSerialPort/QtSerialPortmod.sip               |   2 +-
 sip/QtSql/QtSqlmod.sip                             |   2 +-
 sip/QtSvg/QtSvgmod.sip                             |   2 +-
 sip/QtTest/QtTestmod.sip                           |   2 +-
 sip/QtWebChannel/QtWebChannelmod.sip               |   2 +-
 .../QtWebEnginemod.sip}                            |  13 +-
 sip/QtWebEngine/qquickwebengineprofile.sip         |  93 ++++
 .../QtWebEngine/qtwebengineglobal.sip              |  26 +-
 sip/QtWebEngineCore/QtWebEngineCoremod.sip         |   2 +-
 sip/QtWebEngineCore/qwebengineurlschemehandler.sip |   2 +-
 sip/QtWebEngineWidgets/QtWebEngineWidgetsmod.sip   |   2 +-
 .../qwebenginecertificateerror.sip                 |   3 +
 sip/QtWebEngineWidgets/qwebenginepage.sip          |   2 +-
 sip/QtWebKit/QtWebKitmod.sip                       |   2 +-
 sip/QtWebKitWidgets/QtWebKitWidgetsmod.sip         |   2 +-
 sip/QtWebSockets/QtWebSocketsmod.sip               |   2 +-
 sip/QtWidgets/QtWidgetsmod.sip                     |   2 +-
 sip/QtWidgets/qfiledialog.sip                      |   2 +-
 sip/QtWidgets/qpywidgets_qlist.sip                 |   4 +-
 sip/QtWinExtras/QtWinExtrasmod.sip                 |   2 +-
 sip/QtX11Extras/QtX11Extrasmod.sip                 |   2 +-
 sip/QtXml/QtXmlmod.sip                             |   2 +-
 sip/QtXmlPatterns/QtXmlPatternsmod.sip             |   2 +-
 sip/QtXmlPatterns/qxmlquery.sip                    |  10 +
 .../_QOpenGLFunctions_2_0mod.sip                   |   2 +-
 sip/_QOpenGLFunctions_2_0/qopenglfunctions_2_0.sip |   2 +-
 .../_QOpenGLFunctions_2_1mod.sip                   |   2 +-
 sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip |   2 +-
 .../_QOpenGLFunctions_4_1_Coremod.sip              |   2 +-
 .../qopenglfunctions_4_1_core.sip                  |   2 +-
 .../_QOpenGLFunctions_ES2mod.sip                   |   2 +-
 sip/_QOpenGLFunctions_ES2/qopenglfunctions_es2.sip |   2 +-
 sip/pylupdate/pylupdate_main.py                    |  53 ++-
 sip/pylupdate/pylupdatemod.sip                     |   5 +-
 sip/pyrcc/pyrccmod.sip                             |   2 +-
 176 files changed, 2324 insertions(+), 1377 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index a814c20..f46ed2d 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,8 +1,511 @@
+2016-12-25  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* .hgtags:
+	Added tag 5.7.1 for changeset a25b699c3bff
+	[e6e0f1b22e73] [tip] <5.7-maint>
+
+	* NEWS:
+	Released as v5.7.1.
+	[a25b699c3bff] [5.7.1] <5.7-maint>
+
+2016-12-24  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* lib/configure.py:
+	Link against the correct Python DLL when using the limited API.
+	[b09fa4890933] <5.7-maint>
+
+2016-12-19  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* sphinx/installation.rst:
+	Updated the pyqtlicense documentation.
+	[e8d4a7dff111] <5.7-maint>
+
+2016-12-17  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* QAxContainer/qaxobject.sip:
+	Fixed some very old convertor code in QAxContainer.
+	[1ca987d031ad] <5.7-maint>
+
+2016-12-15  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* PyQt5.msp:
+	Updated for Qt v5.7.1.
+	[5132c77b8800] <5.7-maint>
+
+2016-12-14  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* designer/pluginloader.cpp, designer/pluginloader.h:
+	The Designer plugin now releases the GIL once all plugins have been
+	loaded.
+	[57d8ce89670d] <5.7-maint>
+
+2016-12-04  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* pylupdate/pylupdate_main.py:
+	pylupdate now generates correct relative paths when -ts is used.
+	[1ba3c08d40e4] <5.7-maint>
+
+	* pyuic/uic/uiparser.py:
+	Fixed a crash when a .ui file doesn't contain a button group when it
+	should.
+	[5f3cbec20103] <5.7-maint>
+
+2016-11-25  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* sphinx/installation.rst:
+	Documented the --build-tag command line option to pyqtlicense.
+	[422623d23a48] <5.7-maint>
+
+2016-11-23  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* pyuic/uic/objcreator.py, pyuic/uic/port_v2/invoke.py,
+	pyuic/uic/port_v2/load_plugin.py, pyuic/uic/port_v3/invoke.py,
+	pyuic/uic/port_v3/load_plugin.py, pyuic/uic/pyuic.py:
+	Removed all pyuic code that required Python v2.5 and earlier.
+	[446394da9951] <5.7-maint>
+
+	* sphinx/deploy_commercial.rst, sphinx/extension_api.rst,
+	sphinx/installation.rst, sphinx/introduction.rst,
+	sphinx/pyqt4_differences.rst:
+	All references to the website no wuse https.
+	[16fd5cc19aab] <5.7-maint>
+
+	* qpy/QtQml/qpyqmllistpropertywrapper.cpp:
+	Fixed the QML support when using the limited API.
+	[519b2b27c289] <5.7-maint>
+
+2016-11-14  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* qpy/QtCore/qpycore_types.cpp:
+	Fixed a regression trawling class hierachies using the limited API.
+	[4333b8ba87fd] <5.7-maint>
+
+2016-11-12  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* sphinx/installation.rst:
+	Documented the --qt-version option to pyqtlicense.
+	[d5efc2dd635e] <5.7-maint>
+
+2016-11-10  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* PyQt5.msp:
+	Added a missing /Out/ annotation to
+	QWebEnginePage.javaScriptPrompt().
+	[c5886ff2dc94] <5.7-maint>
+
+2016-11-04  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* qpy/QtCore/qpycore_qobject_helpers.cpp:
+	Fixed a regression in the handling of ReadProperty and WriteProperty
+	in PyQt v5.6 that broke the chapter5-listproperties.py example.
+	[5c3d541a12a2] <5.7-maint>
+
+2016-10-26  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* PyQt5.msp:
+	Added QRegion.setRects().
+	[a7014a7d4259] <5.7-maint>
+
+	* pyuic/uic/widget-plugins/qtcharts.py, pyuic/uic/widget-
+	plugins/qtwebenginewidgets.py:
+	Added widget plugins for QChartView and QWebEngineView.
+	[29003cce4a88] <5.7-maint>
+
+	* PyQt5.msp:
+	Added Qt_5_6_2 to the %Timeline and corresponding values for later
+	versions of Qt v5.6.
+	[9449a57f8e13] <5.7-maint>
+
+2016-10-25  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* PyQt5.msp, qpy/QtCore/qpycore_qstring.cpp:
+	Fixed a regression building against Python v2.
+	[935bb79a7b1c] <5.7-maint>
+
+2016-10-24  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* lib/SubclassCode/mksccode.py:
+	Updated mksccode.py to match the current handling of hidden
+	namespaces.
+	[fbddad196e67] <5.7-maint>
+
+2016-10-14  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* pylupdate/pylupdate_main.py:
+	Fixed a bad call in pylupdate.
+	[9a1caa071647] <5.7-maint>
+
+2016-10-04  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* sphinx/api_metadata.cfg:
+	Added the missing QOpenGLVersionProfile to the documentation.
+	[ed7f40f61a68] <5.7-maint>
+
+2016-09-23  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* PyQt5.msp, qpy/QtCore/qpycore_qmetaobject.cpp,
+	qpy/QtGui/qpyopengl_attribute_array.cpp,
+	qpy/QtGui/qpyopengl_uniform_value_array.cpp,
+	qpy/QtGui/qpyopengl_value_array.cpp:
+	Converted all access to the user object to use the new SIP calls.
+	[71c272511448] <5.7-maint>
+
+	* qpy/QtCore/qpycore_chimera.cpp, qpy/QtCore/qpycore_pyqtsignal.cpp,
+	qpy/QtCore/qpycore_qobject_helpers.cpp,
+	qpy/QtCore/qpycore_types.cpp:
+	Changes needed by the different way of handling plugin generated
+	data.
+	[e9490c8f0819] <5.7-maint>
+
+2016-09-21  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* PyQt5.msp:
+	Updates for the latest SIP changes.
+	[1677ae8bd951] <5.7-maint>
+
+2016-09-19  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* PyQt5.msp:
+	Fixed calls to sipFindType() that were too early.
+	[f04f4d92ab9b] <5.7-maint>
+
+	* PyQt5.msp:
+	Fixes for the latest SIP changes.
+	[81eaffffa555] <5.7-maint>
+
+2016-09-15  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* PyQt5.msp, lib/configure.py, sphinx/api_metadata.cfg,
+	sphinx/introduction.rst:
+	Added the QtWebEngine module.
+	[8c8d065d8148] <5.7-maint>
+
+2016-09-14  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* PyQt5.msp:
+	The byteArray argume to the QBuffer ctor and setBuffer() method must
+	be a QByteArray (and not something that can be converted to a
+	QByteArray) because it needs to outlive the QBuffer instance.
+	[2976e49222bb] <5.7-maint>
+
+	* PyQt5.msp:
+	Added a missing /TransferThis/ to the QWebEngineUrlSchemeHandler
+	ctor.
+	[29be98207b30] <5.7-maint>
+
+	* qpy/QtQml/qpyqmlobject.cpp:
+	Use a unique signal when connecting to a proxy model to allow the
+	model to be used in multiple views.
+	[cd6fbe437e70] <5.7-maint>
+
+2016-09-11  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* QtMacExtras/QtMacExtrasmod.sip, QtMacExtras/qtmac.sip:
+	Added the QtMac namespace to the QtMacExtras module.
+	[581743b7d329] <5.7-maint>
+
+2016-09-10  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* METADATA.in, lib/configure.py, rb-product:
+	Add configuration information to the product file. Specifiy the
+	minimal SIP version in the wheel meta-data.
+	[347419aab38c] <5.7-maint>
+
+2016-09-09  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* qpy/QtGui/qpyopengl_value_array.cpp:
+	Further changes for sipGetBufferInfo().
+	[2dfc32d2117b] <5.7-maint>
+
+	* qpy/QtGui/qpyopengl_value_array.cpp:
+	Fixed the call to sipGetBufferInfo().
+	[842376cb0aa8] <5.7-maint>
+
+2016-09-08  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* qpy/QtCore/qpycore_pyqtproperty.cpp:
+	Fixed regressions in pyqtProperty.
+	[a1d6f69fef7a] <5.7-maint>
+
+	* qpy/QtGui/qpyopengl_attribute_array.cpp, qpy/QtGui/qpyopengl_misc.h,
+	qpy/QtGui/qpyopengl_uniform_value_array.cpp,
+	qpy/QtGui/qpyopengl_value_array.cpp:
+	Fixed the limited API changes when using the PySequence_Fast_*()
+	macros.
+	[04fe0b23b049] <5.7-maint>
+
+	* QAxContainer/QAxContainermod.sip, QAxContainer/qaxbase.sip,
+	QtMacExtras/QtMacExtrasmod.sip, QtWinExtras/QtWinExtrasmod.sip,
+	QtX11Extras/QtX11Extrasmod.sip, pylupdate/pylupdatemod.sip,
+	pyrcc/pyrccmod.sip:
+	The handwritten modules now all use the limited API.
+	[939cc11b2007] <5.7-maint>
+
+	* qpy/QtBluetooth/qpybluetooth_qlist.sip,
+	qpy/QtBluetooth/qpybluetooth_quint128.sip:
+	QtBluetooth now uses the limited API.
+	[dec01d730da6] <5.7-maint>
+
+2016-09-07  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* qpy/QtDBus/qpydbus_chimera_helpers.cpp:
+	QtDBus now uses the limited API.
+	[82a0acefefd3] <5.7-maint>
+
+	* qpy/QtWidgets/qpywidgets_qlist.sip:
+	QtWidgets now uses the limited API.
+	[16de076d88c6] <5.7-maint>
+
+	* qpy/QtQuick/qpyquick_chimera_helpers.cpp:
+	QtQuick now uses the limited API.
+	[a834a23d561b] <5.7-maint>
+
+	* qpy/QtQml/qpyqml_post_init.cpp, qpy/QtQml/qpyqml_qjsvalue.cpp,
+	qpy/QtQml/qpyqml_register_singleton_type.cpp,
+	qpy/QtQml/qpyqml_register_type.cpp,
+	qpy/QtQml/qpyqmllistproperty.cpp, qpy/QtQml/qpyqmllistproperty.h,
+	qpy/QtQml/qpyqmllistproperty.sip,
+	qpy/QtQml/qpyqmllistpropertywrapper.cpp,
+	qpy/QtQml/qpyqmllistpropertywrapper.h:
+	QtQml now uses the limited API.
+	[486082bf4be5] <5.7-maint>
+
+	* qpy/QtPrintSupport/qpyprintsupport_qlist.sip:
+	QtPrintSupport now uses the limited API.
+	[b8c0b62a20a7] <5.7-maint>
+
+	* qpy/QtNetwork/qpynetwork_qhash.sip,
+	qpy/QtNetwork/qpynetwork_qmap.sip:
+	QtNetwork now uses the limited API.
+	[82798213e9a3] <5.7-maint>
+
+	* qpy/QtMultimedia/qpymultimedia_qlist.sip:
+	QtMultimedia now uses the limited API.
+	[6f34d2b297ce] <5.7-maint>
+
+	* PyQt5.msp, qpy/QtGui/qpygui_qlist.sip, qpy/QtGui/qpygui_qpair.sip,
+	qpy/QtGui/qpygui_qvector.sip,
+	qpy/QtGui/qpyopengl_array_convertors.cpp,
+	qpy/QtGui/qpyopengl_attribute_array.cpp,
+	qpy/QtGui/qpyopengl_data_cache.cpp,
+	qpy/QtGui/qpyopengl_data_cache.h, qpy/QtGui/qpyopengl_init.cpp,
+	qpy/QtGui/qpyopengl_uniform_value_array.cpp,
+	qpy/QtGui/qpyopengl_value_array.cpp,
+	qpy/QtGui/qpyopengl_version_functions.cpp:
+	QtGui now uses the limited API.
+	[937e89e76d2d] <5.7-maint>
+
+	* qpy/QtCore/qpycore_pyqtboundsignal.cpp,
+	qpy/QtCore/qpycore_pyqtboundsignal.h,
+	qpy/QtCore/qpycore_pyqtmethodproxy.cpp,
+	qpy/QtCore/qpycore_pyqtmethodproxy.h,
+	qpy/QtCore/qpycore_pyqtproperty.cpp,
+	qpy/QtCore/qpycore_pyqtproperty.h,
+	qpy/QtCore/qpycore_pyqtsignal.cpp, qpy/QtCore/qpycore_pyqtsignal.h:
+	More limited API changes - QtCore now compiles and loads.
+	[d9f7295c5dd7] <5.7-maint>
+
+	* qpy/QtCore/qpycore_qobject_helpers.cpp,
+	qpy/QtCore/qpycore_types.cpp, qpy/QtCore/qpycore_types.h:
+	More limited API changes.
+	[00a8fbb9f360] <5.7-maint>
+
+2016-09-05  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* qpy/QtCore/qpycore_qstring.cpp:
+	The QString convertors now use the limited API.
+	[f57db32b0b5d] <5.7-maint>
+
+	* qpy/QtCore/qpycore_objectified_strings.h,
+	qpy/QtCore/qpycore_post_init.cpp.in,
+	qpy/QtCore/qpycore_public_api.cpp,
+	qpy/QtCore/qpycore_qjsonvalue.cpp,
+	qpy/QtCore/qpycore_qobject_helpers.cpp,
+	qpy/QtCore/qpycore_types.cpp, qpy/QtCore/qpycore_types.h:
+	The QObject helpers now use the limited API.
+	[64c71c6a9ee3] <5.7-maint>
+
+	* qpy/QtCore/qpycore_post_init.cpp.in,
+	qpy/QtCore/qpycore_public_api.cpp,
+	qpy/QtCore/qpycore_pyqtboundsignal.h,
+	qpy/QtCore/qpycore_pyqtproperty.cpp,
+	qpy/QtCore/qpycore_pyqtsignal.cpp, qpy/QtCore/qpycore_pyqtsignal.h,
+	qpy/QtCore/qpycore_pyqtslot.cpp, qpy/QtCore/qpycore_types.cpp:
+	pyqtSignal now uses the limited API.
+	[9caf7074a4fe] <5.7-maint>
+
+	* lib/configure.py, qpy/QtCore/qpycore_post_init.cpp.in,
+	qpy/QtCore/qpycore_pyqtboundsignal.cpp,
+	qpy/QtCore/qpycore_pyqtmethodproxy.cpp,
+	qpy/QtCore/qpycore_pyqtproperty.cpp,
+	qpy/QtCore/qpycore_pyqtproperty.h, qpy/QtCore/qpycore_types.cpp:
+	Python v3.4 is now needed when using the limited API. pyqtProperty
+	now uses the limited API.
+	[4b144ae683bd] <5.7-maint>
+
+	* qpy/QtCore/qpycore_post_init.cpp.in,
+	qpy/QtCore/qpycore_pyqtboundsignal.cpp,
+	qpy/QtCore/qpycore_pyqtmethodproxy.cpp,
+	qpy/QtCore/qpycore_pyqtmethodproxy.h:
+	Moved the method proxy type to the limited API.
+	[ae940422e87f] <5.7-maint>
+
+	* qpy/QtCore/qpycore_post_init.cpp.in,
+	qpy/QtCore/qpycore_public_api.cpp,
+	qpy/QtCore/qpycore_pyqtboundsignal.cpp,
+	qpy/QtCore/qpycore_pyqtboundsignal.h,
+	qpy/QtCore/qpycore_pyqtconfigure.cpp:
+	The bound signal type is now created using the limited API.
+	[326cb5271420] <5.7-maint>
+
+2016-08-30  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* qpy/QtCore/qpycore_public_api.cpp,
+	qpy/QtCore/qpycore_pyqtboundsignal.cpp,
+	qpy/QtCore/qpycore_pyqtslot.cpp:
+	More limited API changes.
+	[caef2e592071] <5.7-maint>
+
+	* qpy/QtCore/qpycore_misc.cpp:
+	Use sipCheckPluginForType().
+	[97c12d786d1e] <5.7-maint>
+
+2016-08-29  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* qpy/QtCore/qpycore_enums_flags.cpp, qpy/QtCore/qpycore_types.cpp:
+	Use sipPyTypeDict() where appropriate.
+	[eb2d099a8804] <5.7-maint>
+
+	* qpy/QtCore/qpycore_classinfo.cpp,
+	qpy/QtCore/qpycore_enums_flags.cpp:
+	Used sipGetFrame() where appropriate.
+	[1d3dbd765934] <5.7-maint>
+
+	* qpy/QtCore/qpycore_chimera.cpp:
+	Use sipIsUserType().
+	[45310e53497b] <5.7-maint>
+
+	* PyQt5.msp, qpy/QtCore/qpycore_pyqtsignal.cpp,
+	qpy/QtCore/qpycore_qlist.sip, qpy/QtCore/qpycore_qpair.sip,
+	qpy/QtCore/qpycore_qvector.sip:
+	Refactored the date/time conversions to use the new SIP calls.
+	[3705eb12433a] <5.7-maint>
+
+2016-08-28  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* PyQt5.msp, qpy/QtCore/qjsonarray.sip, qpy/QtCore/qjsonobject.sip,
+	qpy/QtCore/qpycore_chimera.cpp, qpy/QtCore/qpycore_enums_flags.cpp,
+	qpy/QtCore/qpycore_pyqtboundsignal.cpp,
+	qpy/QtCore/qpycore_pyqtmethodproxy.cpp,
+	qpy/QtCore/qpycore_pyqtsignal.cpp, qpy/QtCore/qpycore_qhash.sip,
+	qpy/QtCore/qpycore_qlist.sip, qpy/QtCore/qpycore_qmap.sip,
+	qpy/QtCore/qpycore_qobject_getattr.cpp,
+	qpy/QtCore/qpycore_qobject_helpers.cpp,
+	qpy/QtCore/qpycore_qpair.sip, qpy/QtCore/qpycore_qset.sip,
+	qpy/QtCore/qpycore_qvector.sip, qpy/QtCore/qpycore_types.cpp,
+	qpy/QtCore/qstringlist.sip:
+	Remove references to tp_name.
+	[f7f509727431] <5.7-maint>
+
+	* PyQt5.msp, qpy/QtCore/qjsonarray.sip,
+	qpy/QtCore/qpycore_chimera.cpp, qpy/QtCore/qpycore_decorators.cpp,
+	qpy/QtCore/qpycore_enums_flags.cpp,
+	qpy/QtCore/qpycore_public_api.cpp,
+	qpy/QtCore/qpycore_pyqtboundsignal.cpp,
+	qpy/QtCore/qpycore_pyqtmethodproxy.cpp,
+	qpy/QtCore/qpycore_pyqtpyobject.cpp,
+	qpy/QtCore/qpycore_pyqtsignal.cpp, qpy/QtCore/qpycore_pyqtslot.cpp,
+	qpy/QtCore/qpycore_qlist.sip, qpy/QtCore/qpycore_qmap.sip,
+	qpy/QtCore/qpycore_qmessagelogger.cpp,
+	qpy/QtCore/qpycore_qmetaobject_helpers.cpp,
+	qpy/QtCore/qpycore_qobject_helpers.cpp,
+	qpy/QtCore/qpycore_qstring.cpp,
+	qpy/QtCore/qpycore_qvariant_value.cpp,
+	qpy/QtCore/qpycore_qvector.sip, qpy/QtCore/qpycore_types.cpp,
+	qpy/QtCore/qstringlist.sip:
+	Started to switch over from the fast macros to the limited API
+	versions.
+	[806af319f405] <5.7-maint>
+
+2016-08-26  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* PyQt5.msp, lib/configure.py, qpy/QtCore/qpycore_init.cpp,
+	qpy/QtCore/qpycore_post_init.cpp.in, qpy/QtCore/qpycore_types.cpp,
+	qpy/QtCore/qpycore_types.h, qpy/QtQml/qpyqmlobject.h:
+	Eliminated the PyQt-specific meta-type.
+	[b88f1ef8bcb0] <5.7-maint>
+
+2016-08-24  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* PyQt5.msp:
+	Enabled the limited API for all modules.
+	[937556c0ec2b] <5.7-maint>
+
+	* PyQt5.msp:
+	Updated the %BIGetBufferCode for the limited API.
+	[94deb582b250] <5.7-maint>
+
+	* lib/configure.py:
+	Updated configure.py to set Py_LIMITED_API for qpy code.
+	[236a19384c91] <5.7-maint>
+
+2016-08-23  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* PyQt5.msp:
+	toString() and toCurrencyString() of QLocale now only overflow if
+	they really have to.
+	[f850c5c9f5b1] <5.7-maint>
+
+	* qpy/QtCore/qpycore_qobject_helpers.cpp:
+	Fixed QObject.inherits().
+	[c7e1a7efb2bf] <5.7-maint>
+
+2016-08-18  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* lib/configure.py:
+	Build modules with 'exceptions_off' rather than special case g++ and
+	clang. Build static modules with 'hide_symbols' to avoid OS X weak
+	symbol warnings.
+	[f02239f94d5e] <5.7-maint>
+
+2016-08-08  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* Makefile, build.py:
+	Removed the old internal build system.
+	[633d0f7fe1b7] <5.7-maint>
+
+2016-08-03  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* qpy/QtCore/qpycore_chimera.cpp:
+	Reverted the conversion of bytes to 'const char *' as the latter is
+	not supported by QMetaType and gives QSignalSpy a problem.
+	[75a3228c629a] <5.7-maint>
+
+	* qpy/pylupdate/pylupdate.h:
+	Fixed the pylupdate changes.
+	[02a9da7b1643] <5.7-maint>
+
+2016-07-27  Phil Thompson  <phil at riverbankcomputing.com>
+
+	* pylupdate/pylupdate_main.py, pylupdate/pylupdatemod.sip,
+	qpy/pylupdate/merge.cpp:
+	Moved a pylupdate progress message to C++ to avoid out-of-order
+	messages.
+	[6f932fba5b39] <5.7-maint>
+
+	* sphinx/introduction.rst:
+	Clarified the docs intro about the inclusion of Qt in wheels.
+	[8d01fcc7cdd0] <5.7-maint>
+
 2016-07-25  Phil Thompson  <phil at riverbankcomputing.com>
 
+	* METADATA.in:
+	Removed the Obsoletes tag from METADATA.
+	[3055d670d1da]
+
 	* .hgtags:
 	Added tag 5.7 for changeset 5e459651a5cb
-	[bb3ddca217a0] [tip]
+	[bb3ddca217a0]
 
 	* NEWS:
 	Released as v5.7.
diff --git a/NEWS b/NEWS
index d6aee15..a4a66df 100644
--- a/NEWS
+++ b/NEWS
@@ -1,3 +1,12 @@
+v5.7.1 25th December 2016
+  - Added support for Qt v5.7.1.
+  - Added the QtWebEngine module.
+  - Added QRegion.setRects().
+  - Added QtMac to the QtMacExtras module.
+  - Added pyuic5 plugins for QChartView and QWebEngineView.
+  - The Python v3.4 limited API is used.
+  - SIP v4.19 is required.
+
 v5.7 25th July 2016
   - Added support for Qt v5.7.0.
 
diff --git a/configure.py b/configure.py
index a44c237..cf2fcc8 100644
--- a/configure.py
+++ b/configure.py
@@ -28,9 +28,9 @@ import sys
 
 
 # Initialise the constants.
-PYQT_VERSION_STR = "5.7"
+PYQT_VERSION_STR = "5.7.1"
 
-SIP_MIN_VERSION = '4.18'
+SIP_MIN_VERSION = '4.19'
 
 # The different values QLibraryInfo::licensee() can return for the LGPL version
 # of Qt.
@@ -97,6 +97,7 @@ MODULE_METADATA = {
     'QtWebChannel':         ModuleMetadata(
                                     qmake_QT=['webchannel', 'network',
                                             '-gui']),
+    'QtWebEngine':          ModuleMetadata(qmake_QT=['webengine', '-gui']),
     'QtWebEngineCore':      ModuleMetadata(qmake_QT=['webenginecore', '-gui']),
     'QtWebEngineWidgets':   ModuleMetadata(
                                     qmake_QT=['webenginewidgets', 'webchannel',
@@ -165,6 +166,7 @@ COMPOSITE_COMPONENTS = (
     'QtWebKitWidgets', 'QtBluetooth', 'QtMacExtras', 'QtPositioning',
         'QtWinExtras', 'QtX11Extras', 'QtQuickWidgets', 'QtWebSockets',
         'Enginio', 'QtWebChannel', 'QtWebEngineCore', 'QtWebEngineWidgets',
+        'QtWebEngine',
     'QtLocation', 'QtNfc'
 )
 
@@ -731,7 +733,12 @@ int main(int argc, char **argv)
 
         if sys.platform == 'win32':
             debug_suffix = get_win32_debug_suffix(debug)
-            pylib_lib = 'python%d%d%s' % (py_major, py_minor, debug_suffix)
+
+            # See if we are using the limited API.
+            if py_major == 3 and py_minor >= 4:
+                pylib_lib = 'python%d%s' % (py_major, debug_suffix)
+            else:
+                pylib_lib = 'python%d%d%s' % (py_major, py_minor, debug_suffix)
 
             pylib_dir = self.py_lib_dir
 
@@ -1440,6 +1447,12 @@ def check_5_6_modules(target_config, disabled_modules, verbose):
             'qtwebenginecoreversion.h',
             'const char *v = QTWEBENGINECORE_VERSION_STR')
 
+    # This may have appeared in an earlier version but this is as far back as
+    # choose to go.
+    check_module(target_config, disabled_modules, verbose, 'QtWebEngine',
+            'qtwebengineversion.h',
+            'const char *v = QTWEBENGINE_VERSION_STR')
+
 
 def generate_makefiles(target_config, verbose, parts, tracing):
     """ Generate the makefiles to build everything.  target_config is the
@@ -2454,7 +2467,7 @@ def generate_module_makefile(target_config, verbose, mname, include_paths=None,
 
     pro_lines = ['TEMPLATE = lib']
 
-    pro_lines.append('CONFIG += warn_on %s' % ('staticlib' if target_config.static else 'plugin'))
+    pro_lines.append('CONFIG += warn_on exceptions_off %s' % ('staticlib hide_symbols' if target_config.static else 'plugin'))
 
     pro_add_qt_dependencies(target_config, metadata, pro_lines)
 
@@ -2499,9 +2512,6 @@ win32 {
             pro_lines.append('sip.files = %s' % ' '.join(sip_files))
             pro_lines.append('INSTALLS += sip')
 
-    if 'g++' in target_config.qmake_spec or 'clang' in target_config.qmake_spec:
-        pro_lines.append('QMAKE_CXXFLAGS += -fno-exceptions')
-
     # This optimisation could apply to other platforms.
     if 'linux' in target_config.qmake_spec and not target_config.static:
         if target_config.py_version >= 0x030000:
@@ -2530,7 +2540,12 @@ win32 {
     if target_config.py_inc_dir != target_config.sip_inc_dir:
         pro_lines.append('INCLUDEPATH += %s' % qmake_quote(target_config.py_inc_dir))
 
-    pro_add_qpy(mname, metadata, pro_lines)
+    if metadata.qpy_lib:
+        # This is the easiest way to make sure it is set for handwritten code.
+        pro_lines.append('DEFINES += Py_LIMITED_API=0x03040000')
+
+        pro_lines.append('INCLUDEPATH += %s' %
+                qmake_quote(os.path.relpath(source_path('qpy', mname), mname)))
 
     if include_paths:
         pro_lines.append(
@@ -2595,17 +2610,6 @@ macx {
     pro.close()
 
 
-def pro_add_qpy(mname, metadata, pro_lines):
-    """ Add the qpy dependencies of a module to a .pro file.  mname is the
-    module's name.  metadata is the module's meta-data.  pro_lines is the list
-    of lines making up the .pro file that is updated.
-    """ 
-
-    if metadata.qpy_lib:
-        pro_lines.append('INCLUDEPATH += %s' %
-                qmake_quote(os.path.relpath(source_path('qpy', mname), mname)))
-
-
 def fix_license(src_lfile, dst_lfile):
     """ Fix the license file, if there is one, so that it conforms to the SIP
     v5 syntax.  src_lfile is the name of the license file.  dst_lfile is the
diff --git a/designer/pluginloader.cpp b/designer/pluginloader.cpp
index 1236ff0..da7ff51 100644
--- a/designer/pluginloader.cpp
+++ b/designer/pluginloader.cpp
@@ -38,7 +38,8 @@
 
 
 // Construct the collection of Python widgets.
-PyCustomWidgets::PyCustomWidgets(QObject *parent) : QObject(parent)
+PyCustomWidgets::PyCustomWidgets(QObject *parent) : QObject(parent),
+        sys_path(0), sip_unwrapinstance(0), qtdesigner_custom(0)
 {
     // Get the default list of directories to search.  These correspond to a
     // standard "python" subdirectory of all the places that Designer looks for
@@ -79,15 +80,6 @@ PyCustomWidgets::PyCustomWidgets(QObject *parent) : QObject(parent)
     else
         dirs = default_dirs;
 
-    // The sys.path object if we need it.
-    PyObject *sys_path = 0;
-
-    // The sip.unwrapinstance object if we need it.
-    PyObject *sip_unwrapinstance = 0;
-
-    // The PyQt5.QtDesigner.QPyDesignerCustomWidgetPlugin object if we need it.
-    PyObject *qtdesigner_custom = 0;
-
     // Go through each directory.
     for (int i = 0; i < dirs.size(); ++i)
     {
@@ -137,152 +129,174 @@ PyCustomWidgets::PyCustomWidgets(QObject *parent) : QObject(parent)
             Py_Initialize();
         }
 
-        // Make sure we have sys.path.
+        // Import the plugins with the GIL held.
+#if defined(WITH_THREAD)
+        PyGILState_STATE gil_state = PyGILState_Ensure();
+#endif
+
+        bool fatal = importPlugins(dir, plugins);
+
+#if defined(WITH_THREAD)
+        PyGILState_Release(gil_state);
+#endif
+
+        if (fatal)
+            break;
+    }
+}
+
+
+// Import the plugins from a directory.
+bool PyCustomWidgets::importPlugins(const QString &dir, const QStringList &plugins)
+{
+    // Make sure we have sys.path.
+    if (!sys_path)
+    {
+        sys_path = getModuleAttr("sys", "path");
+
         if (!sys_path)
-        {
-            sys_path = getModuleAttr("sys", "path");
+            return true;
+    }
 
-            if (!sys_path)
-                return;
-        }
+    // Make sure we have sip.unwrapinstance.
+    if (!sip_unwrapinstance)
+    {
+        sip_unwrapinstance = getModuleAttr("sip", "unwrapinstance");
 
-        // Make sure we have sip.unwrapinstance.
         if (!sip_unwrapinstance)
-        {
-            sip_unwrapinstance = getModuleAttr("sip", "unwrapinstance");
-
-            if (!sip_unwrapinstance)
-                return;
-        }
+            return true;
+    }
 
-        // Convert the directory to a Python object with native separators.
-        dir = QDir::toNativeSeparators(dir);
+    // Convert the directory to a Python object with native separators.
+    QString native_dir = QDir::toNativeSeparators(dir);
 
 #if PY_VERSION_HEX >= 0x03030000
-        PyObject *dobj = PyUnicode_FromKindAndData(PyUnicode_2BYTE_KIND, dir.constData(), dir.length());
+    PyObject *dobj = PyUnicode_FromKindAndData(PyUnicode_2BYTE_KIND, native_dir.constData(), native_dir.length());
 
-        if (!dobj)
-        {
-            PyErr_Print();
-            continue;
-        }
+    if (!dobj)
+    {
+        PyErr_Print();
+        return false;
+    }
 #elif PY_VERSION_HEX >= 0x03000000
 #if defined(Py_UNICODE_WIDE)
-        QVector<uint> ucs4 = dir.toUcs4();
+    QVector<uint> ucs4 = native_dir.toUcs4();
 
-        PyObject *dobj = PyUnicode_FromUnicode(0, ucs4.size());
+    PyObject *dobj = PyUnicode_FromUnicode(0, ucs4.size());
 
-        if (!dobj)
-        {
-            PyErr_Print();
-            continue;
-        }
+    if (!dobj)
+    {
+        PyErr_Print();
+        return false;
+    }
 
-        memcpy(PyUnicode_AS_UNICODE(dobj), ucs4.constData(),
-                ucs4.size() * sizeof (Py_UNICODE));
+    memcpy(PyUnicode_AS_UNICODE(dobj), ucs4.constData(),
+            ucs4.size() * sizeof (Py_UNICODE));
 #else
-        PyObject *dobj = PyUnicode_FromUnicode(0, dir.length());
+    PyObject *dobj = PyUnicode_FromUnicode(0, native_dir.length());
 
-        if (!dobj)
-        {
-            PyErr_Print();
-            continue;
-        }
+    if (!dobj)
+    {
+        PyErr_Print();
+        return false;
+    }
 
-        memcpy(PyUnicode_AS_UNICODE(dobj), dir.utf16(),
-                dir.length() * sizeof (Py_UNICODE));
+    memcpy(PyUnicode_AS_UNICODE(dobj), native_dir.utf16(),
+            native_dir.length() * sizeof (Py_UNICODE));
 #endif
 #else
-        PyObject *dobj = PyString_FromString(dir.toLatin1().constData());
+    PyObject *dobj = PyString_FromString(native_dir.toLatin1().constData());
 
-        if (!dobj)
-        {
-            PyErr_Print();
-            continue;
-        }
+    if (!dobj)
+    {
+        PyErr_Print();
+        return false;
+    }
 #endif
 
-        // Add the directory to sys.path.
-        int rc = PyList_Append(sys_path, dobj);
-        Py_DECREF(dobj);
+    // Add the directory to sys.path.
+    int rc = PyList_Append(sys_path, dobj);
+    Py_DECREF(dobj);
 
-        if (rc < 0)
+    if (rc < 0)
... 7730 lines suppressed ...

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/python-modules/packages/pyqt5.git



More information about the Python-modules-commits mailing list